@@ -1,40 +1,37 @@
 from __future__ import annotations
 
 from asyncio import Future, gather
-from typing import Any, Coroutine, Iterator, TypeVar
+from typing import Any, Awaitable, Generator
 
 import rich.repr
 
-ReturnType = TypeVar("ReturnType")
-
 
 @rich.repr.auto(angular=True)
 class AwaitComplete:
-    """An 'optionally-awaitable' object."""
+    """An 'optionally-awaitable' object which runs one or more coroutines (or other awaitables) concurrently."""
 
-    def __init__(self, *coroutines: Coroutine[Any, Any, Any]) -> None:
+    def __init__(self, *awaitables: Awaitable) -> None:
         """Create an AwaitComplete.
 
         Args:
-            coroutines: One or more coroutines to execute.
+            awaitables: One or more awaitables to run concurrently.
         """
-        self.coroutines: tuple[Coroutine[Any, Any, Any], ...] = coroutines
-        self._future: Future = gather(*self.coroutines)
+        self._future: Future[Any] = gather(*awaitables)
 
     async def __call__(self) -> Any:
         return await self
 
-    def __await__(self) -> Iterator[None]:
+    def __await__(self) -> Generator[Any, None, Any]:
         return self._future.__await__()
 
     @property
     def is_done(self) -> bool:
-        """Returns True if the task has completed."""
+        """`True` if the task has completed."""
         return self._future.done()
 
     @property
     def exception(self) -> BaseException | None:
-        """An exception if it occurred in any of the coroutines."""
+        """An exception if the awaitables failed."""
         if self._future.done():
             return self._future.exception()
         return None
