@@ -24,7 +24,6 @@ if TYPE_CHECKING:
 
 @rich.repr.auto(angular=True)
 class LinuxInlineDriver(Driver):
-
     def __init__(
         self,
         app: App,
@@ -157,7 +156,6 @@ class LinuxInlineDriver(Driver):
             selector.close()
 
     def start_application_mode(self) -> None:
-
         loop = asyncio.get_running_loop()
 
         def send_size_event() -> None:
@@ -178,9 +176,11 @@ class LinuxInlineDriver(Driver):
             signal.signal(signal.SIGWINCH, on_terminal_resize)
 
         self.write("\x1b[?25l")  # Hide cursor
-        self.write("\033[?1004h\n")  # Enable FocusIn/FocusOut.
+        self.write("\033[?1004h")  # Enable FocusIn/FocusOut.
 
         self._enable_mouse_support()
+        self.write("\n")
+        self.flush()
         try:
             self.attrs_before = termios.tcgetattr(self.fileno)
         except termios.error:
@@ -207,6 +207,17 @@ class LinuxInlineDriver(Driver):
         self._key_thread = Thread(target=self._run_input_thread)
         send_size_event()
         self._key_thread.start()
+        self._request_terminal_sync_mode_support()
+        self._enable_bracketed_paste()
+
+    def _request_terminal_sync_mode_support(self) -> None:
+        """Writes an escape sequence to query the terminal support for the sync protocol."""
+        # Terminals should ignore this sequence if not supported.
+        # Apple terminal doesn't, and writes a single 'p' in to the terminal,
+        # so we will make a special case for Apple terminal (which doesn't support sync anyway).
+        if os.environ.get("TERM_PROGRAM", "") != "Apple_Terminal":
+            self.write("\033[?2026$p")
+            self.flush()
 
     @classmethod
     def _patch_lflag(cls, attrs: int) -> int:
@@ -260,7 +271,7 @@ class LinuxInlineDriver(Driver):
         self._disable_bracketed_paste()
         self.disable_input()
 
-        self.write("\x1b[A\x1b[J")
+        self.write("\x1b[2A\x1b[J")
 
         if self.attrs_before is not None:
             try:
@@ -269,6 +280,6 @@ class LinuxInlineDriver(Driver):
                 pass
 
             self.write("\x1b[?25h")  # Show cursor
-            self.write("\033[?1004l\n")  # Disable FocusIn/FocusOut.
+            self.write("\033[?1004l")  # Disable FocusIn/FocusOut.
 
         self.flush()
