@@ -672,30 +672,48 @@ class Screen(Generic[ScreenResultType], Widget):
     def _compositor_refresh(self) -> None:
         """Perform a compositor refresh."""
 
-        if self.app.is_inline:
-            size = self.app.size
-            self.app._display(
-                self,
-                self._compositor.render_inline(
-                    Size(size.width, self._get_inline_height(size)),
-                    screen_stack=self.app._background_screens,
-                ),
-            )
-            self._dirty_widgets.clear()
-            self._compositor._dirty_regions.clear()
+        app = self.app
 
-        elif self is self.app.screen:
-            # Top screen
-            update = self._compositor.render_update(
-                screen_stack=self.app._background_screens
-            )
-            self.app._display(self, update)
-            self._dirty_widgets.clear()
-        elif self in self.app._background_screens and self._compositor._dirty_regions:
-            # Background screen
-            self.app.screen.refresh(*self._compositor._dirty_regions)
-            self._compositor._dirty_regions.clear()
-            self._dirty_widgets.clear()
+        if app.is_inline:
+            if self is app.screen:
+                inline_height = app._get_inline_height()
+                clear = (
+                    app._previous_inline_height is not None
+                    and inline_height < app._previous_inline_height
+                )
+                app._display(
+                    self,
+                    self._compositor.render_inline(
+                        app.size.with_height(inline_height),
+                        screen_stack=app._background_screens,
+                        clear=clear,
+                    ),
+                )
+                app._previous_inline_height = inline_height
+                self._dirty_widgets.clear()
+                self._compositor._dirty_regions.clear()
+            elif (
+                self in self.app._background_screens and self._compositor._dirty_regions
+            ):
+                app.screen.refresh(*self._compositor._dirty_regions)
+                self._compositor._dirty_regions.clear()
+                self._dirty_widgets.clear()
+
+        else:
+            if self is app.screen:
+                # Top screen
+                update = self._compositor.render_update(
+                    screen_stack=app._background_screens
+                )
+                app._display(self, update)
+                self._dirty_widgets.clear()
+            elif (
+                self in self.app._background_screens and self._compositor._dirty_regions
+            ):
+                # Background screen
+                app.screen.refresh(*self._compositor._dirty_regions)
+                self._compositor._dirty_regions.clear()
+                self._dirty_widgets.clear()
 
     def _on_timer_update(self) -> None:
         """Called by the _update_timer."""
@@ -775,7 +793,7 @@ class Screen(Generic[ScreenResultType], Widget):
         """Refresh the layout (can change size and positions of widgets)."""
         size = self.outer_size if size is None else size
         if self.app.is_inline:
-            size = Size(size.width, self._get_inline_height(self.app.size))
+            size = size.with_height(self.app._get_inline_height())
         if not size:
             return
         self._compositor.update_widgets(self._dirty_widgets)
@@ -889,7 +907,7 @@ class Screen(Generic[ScreenResultType], Widget):
             inline_height = max(inline_height, int(min_height.resolve(size, size)))
         if max_height is not None:
             inline_height = min(inline_height, int(max_height.resolve(size, size)))
-        inline_height = min(self.app.size.height - 1, inline_height)
+        inline_height = min(self.app.size.height, inline_height)
         return inline_height
 
     def _screen_resized(self, size: Size):
